==> tv_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/pricing/ServiceOffering.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.pricing;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for serviceOffering complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="serviceOffering">
 *   &lt;complexContent>
 *     &lt;extension base="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}interaction">
 *       &lt;sequence>
 *         &lt;element name="price" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}price" minOccurs="0"/>
 *         &lt;element name="service" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}service" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "serviceOffering", propOrder = {
    "price",
    "service"
})
public class ServiceOffering
    extends Interaction
{

    protected Price price;
    protected Service service;

    /**
     * Gets the value of the price property.
     * 
     * @return
     *     possible object is
     *     {@link Price }
     *     
     */
    public Price getPrice() {
        return price;
    }

    /**
     * Sets the value of the price property.
     * 
     * @param value
     *     allowed object is
     *     {@link Price }
     *     
     */
    public void setPrice(Price value) {
        this.price = value;
    }

    /**
     * Gets the value of the service property.
     * 
     * @return
     *     possible object is
     *     {@link Service }
     *     
     */
    public Service getService() {
        return service;
    }

    /**
     * Sets the value of the service property.
     * 
     * @param value
     *     allowed object is
     *     {@link Service }
     *     
     */
    public void setService(Service value) {
        this.service = value;
    }

}

==> tv_9.2410-2507291416.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/pricing/ServiceOffering.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.pricing;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for serviceOffering complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="serviceOffering">
 *   &lt;complexContent>
 *     &lt;extension base="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}interaction">
 *       &lt;sequence>
 *         &lt;element name="price" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}price" minOccurs="0"/>
 *         &lt;element name="service" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}service" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "serviceOffering", propOrder = {
    "price",
    "service"
})
public class ServiceOffering
    extends Interaction
{

    protected Price price;
    protected Service service;

    /**
     * Gets the value of the price property.
     * 
     * @return
     *     possible object is
     *     {@link Price }
     *     
     */
    public Price getPrice() {
        return price;
    }

    /**
     * Sets the value of the price property.
     * 
     * @param value
     *     allowed object is
     *     {@link Price }
     *     
     */
    public void setPrice(Price value) {
        this.price = value;
    }

    /**
     * Gets the value of the service property.
     * 
     * @return
     *     possible object is
     *     {@link Service }
     *     
     */
    public Service getService() {
        return service;
    }

    /**
     * Sets the value of the service property.
     * 
     * @param value
     *     allowed object is
     *     {@link Service }
     *     
     */
    public void setService(Service value) {
        this.service = value;
    }

}
